# Ruth's functions as requested by Carol and Rachael. 

# ---------
# LINES Function
# ---------
#' @title Output of PCoD simulations as lines
#' @description
#' @param dat.out  \code{transects}
#' @examples 

LINES <- function (dat.out,simulated.years=2016:(2016+years-2),Dist_mean,Undist_mean, nlines=100) {
# -----
data.out=(ifelse(dat.out[,1:2,]<0,0,dat.out[,1:2,])) 
if (length(simulated.years)>length(Undist_mean[!is.na(Undist_mean)])) {stop("simulated.years is longer than projected data series")}
plot(0,0, ylim = range(dat.out[,1:2,],na.rm=T), xlim = range(simulated.years),pch=".", xlab="Year",ylab="Population size",axes=F)
	for(i in 1:nlines)(lines(simulated.years[1:length(data.out[!is.na(data.out[,2,i]),1,i])],
					  data.out[!is.na(data.out[,2,i]),2,i],col=rgb(0,0,1,.1)))
	lines(simulated.years[!is.na(Undist_mean)], Undist_mean[!is.na(Undist_mean)], col = rgb(0,0,1,1))
	legend("topleft",col=c(rgb(0,0,1,1),rgb(0,0,1,.3)),
		legend=c("Un-impacted mean","Simulated outcome"),bty="n",lty=1,cex=1.3)
	axis(1,cex.axis=1.3);box()
	axis(2,las=2,cex.axis=1.3)
	mtext(side=3,"Un-impacted Population",line=0.5,outer=F)
# -----
plot(0,0, ylim = range(data.out[,1:2,],na.rm=T), xlim = range(simulated.years),pch=".", xlab="Year",ylab="Population size",axes=F)
	for(i in 1:nlines)(lines(simulated.years[1:length(data.out[!is.na(data.out[,1,i]),1,i])],
					  data.out[!is.na(data.out[,1,i]),1,i],col=rgb(1,0,0,.1)))
	lines(simulated.years[!is.na(Dist_mean)], Dist_mean[!is.na(Dist_mean)],col=rgb(1,0,0,1))
	legend("topleft",col=c(rgb(1,0,0,1),rgb(1,0,0,.3)),
		legend=c("Impacted mean","Simulated outcome"),bty="n",lty=1,cex=1.3)
	axis(1,cex.axis=1.3);box()
	mtext(side=3,"Impacted Population",line=0.5,outer=F)
# -----
plot(0,0, ylim = range(data.out[,1:2,],na.rm=T), xlim = range(simulated.years),pch=".", xlab="Year",ylab="Population size",axes=F)
	for(i in 1:nlines)(lines(simulated.years[1:length(data.out[!is.na(data.out[,1,i]),1,i])],
					  data.out[!is.na(data.out[,1,i]),1,i],col=rgb(1,0,0,.1)))
	for(i in 1:nlines)(lines(simulated.years[1:length(data.out[!is.na(data.out[,2,i]),1,i])],
					  data.out[!is.na(data.out[,2,i]),2,i],col=rgb(0,0,1,.1)))
	lines(simulated.years[!is.na(Dist_mean)], Dist_mean[!is.na(Dist_mean)],col=rgb(1,0,0,1))
	lines(simulated.years[!is.na(Undist_mean)], Undist_mean[!is.na(Undist_mean)], col = rgb(0,0,1,1))
	axis(1,cex.axis=1.3);box()
	axis(4,las=2,label=F)
	mtext(side=3,"Both Populations",line=0.5,outer=F)
	mtext(side=1,"Year",line=2,outer=T)
	mtext(side=2,"Population Number",line=4,outer=T)
	}
	

# ---------
# POLYGONS function (edited Feb 21, 2018)
# ---------
POLYGONS <- function (dat.out,simulated.years=2016:(2016+years-2),Dist_mean,Undist_mean) {
# -----
data.out=(ifelse(dat.out[,1:2,]<0,0,dat.out[,1:2,]))
plot(0,0, ylim = range(data.out[,1:2,],na.rm=T), xlim = range(simulated.years),pch=".", xlab="year",ylab="Population size",axes=F)
#		CI2 <- apply(data.out[1:sum(!is.na(data.out[,2,1])),2,],1,quantile,c(.025,.975))
		CI2 <- apply(data.out[1:length(simulated.years),2,],1,quantile,c(.025,.975))
	polygon(c(simulated.years[1:ncol(CI2)],rev(simulated.years[1:ncol(CI2)])),	c(CI2[1,],rev(CI2[2,])),col=rgb(0,0,1,.2),border=F)		
		lines(simulated.years[!is.na(Undist_mean)], Undist_mean[!is.na(Undist_mean)], col = rgb(0,0,1,1))
	legend("topleft",col=c(rgb(0,0,1,1),rgb(0,0,1,.3)),
		legend=c("Mean Projection","95% CI for Projection"),
		fill=c(rgb(0,0,0,0),rgb(0,0,1,.3)),bty="n",lty=c(1,0),border=F,cex=1.3)
	axis(1,cex.axis=1.3);box()
	axis(2,las=2,cex.axis=1.3)
	mtext(side=3,"Un-impacted Population",line=0.5,outer=F)
# -----
plot(0,0, ylim = range(data.out[,1:2,],na.rm=T), xlim = range(simulated.years),pch=".", xlab="Year",ylab="Population size",axes=F)
#		CI1 <- apply(data.out[1:sum(!is.na(data.out[,1,1])),1,],1,quantile,c(.025,.975))
		CI1 <- apply(data.out[1:length(simulated.years),1,],1,quantile,c(.025,.975))
	polygon(c(simulated.years[1:ncol(CI1)],rev(simulated.years[1:ncol(CI1)])),	c(CI1[1,],rev(CI1[2,])),col=rgb(1,0,0,.2),border=F)		
	lines(simulated.years[!is.na(Dist_mean)], Dist_mean[!is.na(Dist_mean)],col=rgb(1,0,0,1))
	legend("topleft",col=c(rgb(1,0,0,1),rgb(1,0,0,.3)),
		legend=c("Mean Projection","95% CI for Projection"),
		fill=c(rgb(0,0,0,0),rgb(1,0,0,.3)),bty="n",lty=c(1,0),border=F,cex=1.3)
	axis(1,cex.axis=1.3);box()
	mtext(side=3,"Impacted Population",line=0.5,outer=F)
# -----
plot(0,0, ylim = range(data.out[,1:2,],na.rm=T), xlim = range(simulated.years),pch=".", xlab="year",ylab="Population size",axes=F)
	polygon(c(simulated.years[1:ncol(CI1)],rev(simulated.years[1:ncol(CI1)])),	c(CI1[1,],rev(CI1[2,])),col=rgb(1,0,0,.2),border=F)		
	polygon(c(simulated.years[1:ncol(CI2)],rev(simulated.years[1:ncol(CI2)])),	c(CI2[1,],rev(CI2[2,])),col=rgb(0,0,1,.2),border=F)		
	lines(simulated.years[!is.na(Dist_mean)], Dist_mean[!is.na(Dist_mean)],col=rgb(1,0,0,1))
		lines(simulated.years[!is.na(Undist_mean)], Undist_mean[!is.na(Undist_mean)], col = rgb(0,0,1,1))
	axis(1,cex.axis=1.3);box()
	axis(4,las=2,label=F)
	mtext(side=3,"Both Populations",line=.5,outer=F)
	mtext(side=1,"Year",line=2,outer=T)
	mtext(side=2,"Population Number",line=4,outer=T)
	}


# ---------------------------------------------------------
# function to calculate mean, median, and %CI's 
# for baseline and impacted population
# --  (edited for Feb 21, 2018)
# -- changed column headings so 95% CI has 2.5%, and 97.5% now
# -- allows there to be only 1 point for the time.point vector
# ---------------------------------------------------------
CUSTOM.TABLE <- function(dat.out, time.points=c(1,5,10,15,24), percent.CI=c(95), get.median=T) {
data.out=(ifelse(dat.out[,1:2,]<0,0,dat.out[,1:2,]))
	if (sum(!is.element(time.points , 1:length(data.out[!is.na(data.out[,1,i]),1,i])))>0)  
				{stop(gettextf("one or more time.points outside of simulation range"),domain=NA)}
 	if (sum(!is.element(time.points , 1:length(data.out[!is.na(data.out[,1,i]),1,i])))==0)
		 {quant=c(abs((rep(1,length(percent.CI))-rev(percent.CI)/100)/2+rep(c(0,-1),each=length(percent.CI))))
		 							quantiles=quant[c(matrix(1:(2*length(percent.CI)),byrow=T,nrow=2))]

		  if (get.median)  quantiles=c(.5,quantiles)

		out.table <- matrix(NA, length(time.points),2*(1+length(quantiles)))

		# impacted
		out.table[,(length(quantiles)+3):(2*(1+1*length(quantiles)))] <- t(apply(matrix(data.out[time.points,1,],nrow=length(time.points)),1,quantile,quantiles))
		# baseline
		out.table[,2:(1+length(quantiles))] <- t(apply(matrix(data.out[time.points,2,],nrow=length(time.points)),1,quantile,quantiles))
			
		out.table[,c((2+length(quantiles)))] <- apply(matrix(data.out[time.points,1,],nrow=length(time.points)),1,mean)
		
		out.table[,c(1)] <- apply(matrix(data.out[time.points,2,],nrow=length(time.points)),1,mean)

		rownames(out.table)=paste("time.point",time.points,sep=".")
		colnames(out.table)=paste(rep(c("un-impacted","impacted"),each=(1+length(quantiles))),
						paste("pop",c("mean",
						ifelse(quantiles==.5,"median",ifelse(quantiles<.5,paste("lower ",100* quantiles,"%",sep=""),
								paste("upper ",100-100*(1-quantiles),"%",sep=""))) ),sep=" " ) ,sep=" ")

		return(custom.table=out.table)}
	}

# ---------------------------------------------------------
# function that return what Carol Sparling wanted
# which was get the centiles for a single time.point of the baseline population
# and return which baseline centile is closest to the median of the impacted population
# ---------------------------------------------------------
CENTILES <- function(dat.out, time.point) {

if (time.point>length(dat.out[,1,1]))
				{stop("time.point is outside of simulation range")}
if (time.point<=length(dat.out[,1,1]))
				{
  centiles <- CUSTOM.TABLE(dat.out, time.points=time.point, percent.CI=seq(2,98,2), get.median=T)

  cent.table <- data.frame(which.lower.centile=c(unlist(lapply(strsplit(names(centiles[,grep('un-impacted pop lower',dimnames(centiles)[[2]])])," "),'[[',4)),'50%'),
	lower.centile=unname(c(centiles[,grep('un-impacted pop lower',dimnames(centiles)[[2]])],centiles[,'un-impacted pop median'])), 
	which.upper.centile=c(unlist(lapply(strsplit(names(centiles[,grep('un-impacted pop upper',dimnames(centiles)[[2]])])," "),'[[',4)),'50%'),
	upper.centile=unname(c(centiles[,grep('un-impacted pop upper',dimnames(centiles)[[2]])],centiles[,'un-impacted pop median'])))

# median of impact population
  med.impact <- centiles[,grep('impacted pop median',
						dimnames(centiles)[[2]])][1] # there can only be 1
	low <- abs(med.impact-cent.table$lower.centile)[which.min(abs(med.impact-cent.table$lower.centile))]
	upp <- abs(med.impact-cent.table$upper.centile)[which.min(abs(med.impact-cent.table$upper.centile))]
	med <-  abs(med.impact-centiles[,grep('un-impacted pop median',
						dimnames(centiles)[[2]])][1]) # abs(med.impact-med.baseline)


  closest.centile <- c((as.character(cent.table$which.lower.centile[which.min(abs(med.impact-cent.table$lower.centile))])),
 as.character("50%"),
  	(as.character(cent.table$which.upper.centile[which.min(abs(med.impact-cent.table$upper.centile))])))[which.min(c(low,med,upp))]

  return(list(baseline.pop.centiles=cent.table, 
  		median.for.impact.pop=med.impact , 
  		closest.centile= closest.centile))
  		}
}

# CENTILES(dat.out, time.point=20)

#CENTILES TABLE
CENTILES.TABLE<- function(dat.out, time.points) {
  closest.cent=  sapply(c(time.points), function(time.points) CENTILES(dat.out, time.point=time.points)$closest.centile )
  return(data.frame(time.points=time.points,closest.cent=closest.cent))
}

# CENTILES.TABLE(dat.out, time.points=c(2:25))

# ---------------------------------------------------------
# function to histograms for a time.point
# for baseline and impacted population
# ---------------------------------------------------------

HISTOGRAMS <- function(dat.out, time.point=26, axis_breaks=seq(0,700000,50000)) {
  data.out=(ifelse(dat.out[,1:2,]<0,0,dat.out[,1:2,])); back_breaks=axis_breaks
  baseline.hist <- hist(data.out[time.point,2,],plot=F,breaks=axis_breaks)
  impact.hist <- hist(data.out[time.point,1,],plot=F,breaks=axis_breaks)
  # --
  a=barplot(baseline.hist$counts,space=0,col=rgb(0,0,1,.7),density=25,angle=135,
            axisnames=F,axes=F,ylim=c(0,max(c(baseline.hist$counts,impact.hist$counts))))
  axis(1,at=c(a-.5,max(a)+.5)[is.element(back_breaks,axis_breaks)],label=axis_breaks,las=1,cex.axis=1.3)
  axis(2,las=2,cex.axis=1.3)
  mtext(side=3,"Un-impacted Population",line=.5,outer=F)
  
  # --
  a=barplot(impact.hist$counts,space=0,col=rgb(1,0,0,.7),density=25,angle=45,
            axisnames=F,axes=F,ylim=c(0,max(c(baseline.hist$counts,impact.hist$counts))))
  axis(1,at=c(a-.5,max(a)+.5)[is.element(back_breaks,axis_breaks)],label=axis_breaks,las=1,cex.axis=1.3)
  mtext(side=3,"Impacted Population",line=.5,outer=F)
  # --
  a=barplot(baseline.hist$counts,space=0,col=rgb(0,0,1,.7),axisnames=F,density=25,angle=135,
            axes=F,ylim=c(0,max(c(baseline.hist$counts,impact.hist$counts))))
  axis(1,at=c(a-.5,max(a)+.5)[is.element(back_breaks,axis_breaks)],label=axis_breaks,las=1,cex.axis=1.3)
  a=barplot(impact.hist$counts,space=0,col=rgb(1,0,0,.7),axisnames=F,density=25,angle=45,
            axes=F,ylim=c(0,max(c(baseline.hist$counts,impact.hist$counts))),add=T)
  axis(1,at=c(a-.5,max(a)+.5)[is.element(back_breaks,axis_breaks)],label=axis_breaks,las=1,cex.axis=1.3)
  axis(4,las=2,cex.axis=1.3)
  
  mtext(side=3,"Both Populations",line=.5,outer=F)
  mtext(side=1,"Population Size",line=2,outer=T)
  mtext(side=2,"Number Sequences Run per Bar",line=4,outer=T)
  
}



# ---------------------------------------------------------

RATIOS <- function(dat.out, time.point=1) {
  data.out=(ifelse(dat.out[,1:2,]<0,0,dat.out[,1:2,]))
  pretty.breaks <- pretty(c(min(data.out[time.point,1,]/data.out[time.point,2,]), 
                            max(data.out[time.point,1,]/data.out[time.point,2,]),1),shrink=.001)
  # --
  # axis.breaks
  if (length(pretty.breaks)==2) 
  {axis.breaks = seq(-diff(pretty.breaks),diff(pretty.breaks),l=4) + c(pretty.breaks[length(pretty.breaks)])}
  if (length(pretty.breaks)!=2) 
  {axis.breaks = (pretty.breaks)}
  # --
  ratio.hist <- hist(data.out[time.point,1,]/data.out[time.point,2,], plot=F, breaks=axis.breaks)
  # --
  a=barplot(ratio.hist$counts/sum(ratio.hist$counts), space=0,col=rgb(.4,.4,.4,.5),density=25,angle=135,
            axisnames=F,axes=F,ylim=c(0,1.05*max(ratio.hist$counts/sum(ratio.hist$counts),na.rm=T)))
  axis(1,at=c(a),label=round(ratio.hist$mids,4),las=1,cex.axis=1.3)
  axis(2,las=2,cex.axis=1.3)
  mtext(side=1,"Ratio of Impacted to Un-impacted Population",line=3.0,outer=T,cex=1.3)
  #	mtext(side=3,expression("(Ratio < 1 implies population decline, Ratio = 1 implies no impact, Ratio > 1 implies population growth)"),line=4.2,outer=F,cex=1.0)
  box()
  mtext(side=3,#a[1],1.4*max(ratio.hist$counts/sum(ratio.hist$counts),na.rm=T), legend=
        c("Ratio < 1 implies population decline"), line=2, outer=T,adj=0)
  mtext(side=3,#a[1],1.4*max(ratio.hist$counts/sum(ratio.hist$counts),na.rm=T), legend=
        c("Ratio = 1 implies no impact"), line=1, outer=T,adj=0)
  mtext(side=3,#a[1],1.4*max(ratio.hist$counts/sum(ratio.hist$counts),na.rm=T), legend=
        c("Ratio > 1 implies population growth"), line=0, outer=T,adj=0)
  
  legend('topright', legend=paste("time.point",time.point," "),cex=1.0, xpd=NA, bty='n')
  
  # --
  mtext(side=2,"Proportion of Estimated Ratios\nContained by Each Bar",line=2.7,outer=T, cex=1.3)
  # -- 
  # vertical red line at 1.0
  # if (sum(round(ratio.hist$mids,4)==1)==0) {abline(v=a[which(axis.breaks==1)-1]+.5,lwd=3,col=rgb(1,0,0,.3)) }
  #if (sum(round(ratio.hist$mids,4)==1)!=0) {abline(v=a[which(round(ratio.hist$mids,4)==1)],lwd=3,col=rgb(1,0,0,.3)) }
}


#################################################################################################

### GROWTH RATE

# calculate the ratios
GRtime.point2<-(100+dat.out[2,4,])/(100+dat.out[2,5,])
GRtime.point3<-(100+dat.out[3,4,])/(100+dat.out[3,5,])
GRtime.point4<-(100+dat.out[4,4,])/(100+dat.out[4,5,])
GRtime.point5<-(100+dat.out[5,4,])/(100+dat.out[5,5,])
GRtime.point6<-(100+dat.out[6,4,])/(100+dat.out[6,5,])
GRtime.point7<-(100+dat.out[7,4,])/(100+dat.out[7,5,])
GRtime.point8<-(100+dat.out[8,4,])/(100+dat.out[8,5,])
GRtime.point9<-(100+dat.out[9,4,])/(100+dat.out[9,5,])
GRtime.point10<-(100+dat.out[10,4,])/(100+dat.out[10,5,])
GRtime.point11<-(100+dat.out[11,4,])/(100+dat.out[11,5,])
GRtime.point12<-(100+dat.out[12,4,])/(100+dat.out[12,5,])
GRtime.point13<-(100+dat.out[13,4,])/(100+dat.out[13,5,])
GRtime.point14<-(100+dat.out[14,4,])/(100+dat.out[14,5,])
GRtime.point15<-(100+dat.out[15,4,])/(100+dat.out[15,5,])
GRtime.point16<-(100+dat.out[16,4,])/(100+dat.out[16,5,])
GRtime.point17<-(100+dat.out[17,4,])/(100+dat.out[17,5,])
GRtime.point18<-(100+dat.out[18,4,])/(100+dat.out[18,5,])
GRtime.point19<-(100+dat.out[19,4,])/(100+dat.out[19,5,])
GRtime.point20<-(100+dat.out[20,4,])/(100+dat.out[20,5,])
GRtime.point21<-(100+dat.out[21,4,])/(100+dat.out[21,5,])
GRtime.point22<-(100+dat.out[22,4,])/(100+dat.out[22,5,])
GRtime.point23<-(100+dat.out[23,4,])/(100+dat.out[23,5,])
GRtime.point24<-(100+dat.out[24,4,])/(100+dat.out[24,5,])
GRtime.point25<-(100+dat.out[25,4,])/(100+dat.out[25,5,])
GRtime.point26<-(100+dat.out[26,4,])/(100+dat.out[26,5,])


# summarise the outputs
GRtime.point2summary<-c("Mean"=mean(GRtime.point2),   "Median"=median(GRtime.point2),  "1st Qu"=quantile(GRtime.point2, 0.25),  "3rd Qu"=quantile(GRtime.point2, 0.75))
GRtime.point3summary<-c("Mean"=mean(GRtime.point3),   "Median"=median(GRtime.point2),  "1st Qu"=quantile(GRtime.point3, 0.25),  "3rd Qu"=quantile(GRtime.point3, 0.75))
GRtime.point4summary<-c("Mean"=mean(GRtime.point4),   "Median"=median(GRtime.point2),  "1st Qu"=quantile(GRtime.point4, 0.25),  "3rd Qu"=quantile(GRtime.point4, 0.75))
GRtime.point5summary<-c("Mean"=mean(GRtime.point5),   "Median"=median(GRtime.point2),  "1st Qu"=quantile(GRtime.point5, 0.25),  "3rd Qu"=quantile(GRtime.point5, 0.75))
GRtime.point6summary<-c("Mean"=mean(GRtime.point6),   "Median"=median(GRtime.point2),  "1st Qu"=quantile(GRtime.point6, 0.25),  "3rd Qu"=quantile(GRtime.point6, 0.75))
GRtime.point7summary<-c("Mean"=mean(GRtime.point7),   "Median"=median(GRtime.point7),  "1st Qu"=quantile(GRtime.point7, 0.25),  "3rd Qu"=quantile(GRtime.point7, 0.75))
GRtime.point8summary<-c("Mean"=mean(GRtime.point8),   "Median"=median(GRtime.point8),  "1st Qu"=quantile(GRtime.point8, 0.25),  "3rd Qu"=quantile(GRtime.point8, 0.75))
GRtime.point9summary<-c("Mean"=mean(GRtime.point9),   "Median"=median(GRtime.point9),  "1st Qu"=quantile(GRtime.point9, 0.25),  "3rd Qu"=quantile(GRtime.point9, 0.75))
GRtime.point10summary<-c("Mean"=mean(GRtime.point10), "Median"=median(GRtime.point10), "1st Qu"=quantile(GRtime.point10, 0.25), "3rd Qu"=quantile(GRtime.point10, 0.75))
GRtime.point11summary<-c("Mean"=mean(GRtime.point11), "Median"=median(GRtime.point11), "1st Qu"=quantile(GRtime.point11, 0.25), "3rd Qu"=quantile(GRtime.point11, 0.75))
GRtime.point12summary<-c("Mean"=mean(GRtime.point12), "Median"=median(GRtime.point12), "1st Qu"=quantile(GRtime.point12, 0.25), "3rd Qu"=quantile(GRtime.point12, 0.75))
GRtime.point13summary<-c("Mean"=mean(GRtime.point13), "Median"=median(GRtime.point13), "1st Qu"=quantile(GRtime.point13, 0.25), "3rd Qu"=quantile(GRtime.point13, 0.75))
GRtime.point14summary<-c("Mean"=mean(GRtime.point14), "Median"=median(GRtime.point14), "1st Qu"=quantile(GRtime.point14, 0.25), "3rd Qu"=quantile(GRtime.point14, 0.75))
GRtime.point15summary<-c("Mean"=mean(GRtime.point15), "Median"=median(GRtime.point15), "1st Qu"=quantile(GRtime.point15, 0.25), "3rd Qu"=quantile(GRtime.point15, 0.75))
GRtime.point16summary<-c("Mean"=mean(GRtime.point16), "Median"=median(GRtime.point16), "1st Qu"=quantile(GRtime.point16, 0.25), "3rd Qu"=quantile(GRtime.point16, 0.75))
GRtime.point17summary<-c("Mean"=mean(GRtime.point17), "Median"=median(GRtime.point17), "1st Qu"=quantile(GRtime.point17, 0.25), "3rd Qu"=quantile(GRtime.point17, 0.75))
GRtime.point18summary<-c("Mean"=mean(GRtime.point18), "Median"=median(GRtime.point18), "1st Qu"=quantile(GRtime.point18, 0.25), "3rd Qu"=quantile(GRtime.point18, 0.75))
GRtime.point19summary<-c("Mean"=mean(GRtime.point19), "Median"=median(GRtime.point19), "1st Qu"=quantile(GRtime.point19, 0.25), "3rd Qu"=quantile(GRtime.point19, 0.75))
GRtime.point20summary<-c("Mean"=mean(GRtime.point20), "Median"=median(GRtime.point20), "1st Qu"=quantile(GRtime.point20, 0.25), "3rd Qu"=quantile(GRtime.point20, 0.75))
GRtime.point21summary<-c("Mean"=mean(GRtime.point21), "Median"=median(GRtime.point21), "1st Qu"=quantile(GRtime.point21, 0.25), "3rd Qu"=quantile(GRtime.point21, 0.75))
GRtime.point22summary<-c("Mean"=mean(GRtime.point22), "Median"=median(GRtime.point22), "1st Qu"=quantile(GRtime.point22, 0.25), "3rd Qu"=quantile(GRtime.point22, 0.75))
GRtime.point23summary<-c("Mean"=mean(GRtime.point23), "Median"=median(GRtime.point23), "1st Qu"=quantile(GRtime.point23, 0.25), "3rd Qu"=quantile(GRtime.point23, 0.75))
GRtime.point24summary<-c("Mean"=mean(GRtime.point24), "Median"=median(GRtime.point24), "1st Qu"=quantile(GRtime.point24, 0.25), "3rd Qu"=quantile(GRtime.point24, 0.75))
GRtime.point25summary<-c("Mean"=mean(GRtime.point25), "Median"=median(GRtime.point25), "1st Qu"=quantile(GRtime.point25, 0.25), "3rd Qu"=quantile(GRtime.point25, 0.75))
GRtime.point26summary<-c("Mean"=mean(GRtime.point26), "Median"=median(GRtime.point26), "1st Qu"=quantile(GRtime.point26, 0.25), "3rd Qu"=quantile(GRtime.point26, 0.75))

GRratiotable<-rbind(GRtime.point2summary, GRtime.point3summary, GRtime.point4summary, GRtime.point5summary, GRtime.point6summary, GRtime.point7summary, GRtime.point8summary, 
                    GRtime.point9summary, GRtime.point10summary, GRtime.point11summary, GRtime.point12summary, GRtime.point13summary, GRtime.point14summary, GRtime.point15summary, 
                    GRtime.point16summary, GRtime.point17summary, GRtime.point18summary, GRtime.point19summary, GRtime.point20summary, GRtime.point21summary, GRtime.point22summary, 
                    GRtime.point23summary, GRtime.point24summary, GRtime.point25summary, GRtime.point26summary)









