# This code allow users to set all relevant parameters in one location. 
# It will be sourced first during any computer run and parameters will be updated from these values
rm(list = ls())


# Set code that will be used to name the results file and the model summary file
# It must be within the double quotes (" ") 
# and must be one that is recognised by R (no blanks, for example)
run_ID <- "_ver5test"

# Set the number of times you want to run the simulation 
nboot <- 1000

# set species code. Here are the valid values: 
# BND = bottlenose dolphin
# GS = grey seal
# HP = harbour porpoise
# HS = harbour seal
# MW = minke whale
spec <- 'HP'

# Use "spec" to chose which MakeInit file to run
if(spec == 'BND'){minit.file <- 'MakeInitScenarioBND_ver4.R'}
if(spec == 'GS'){minit.file <- 'MakeInitScenarioGS_ver5b.R'}
if(spec == 'HP'){minit.file <- 'MakeInitScenarioHP_ver5b.R'}
if(spec == 'HS'){minit.file <- 'MakeInitScenarioHS_ver5b.R'}
if(spec == 'MW'){minit.file <- 'MakeInitScenarioMW_ver4.R'}

# Set proportions of females in the population 
propfemale <- 0.5

# Set population size
pmean <-345373

# Set threshold size for demographic stochasticity
# Demographic stochasticity will be implemented if pmean*propfemale < threshold
threshold <- 500

Surv <- rep(0,18)

# Set calf/pup survival
Surv[1] <- 0.8455
# Set juvenile survival
Surv[7] <- 0.88
# Set adult survival
Surv[13] <- 0.925
# Set fecundity rate
Fertility <- 0.34
# Set age at which a calf or pup becomes independent of its mother
age1 <- 1
# Set age at which an average female gives birth to her first calf
age2 <- 5

# Set number of years on which piling will occur. 
# Set this to zero if there is no piling or you only want to model the effect of collisions
pile_years <- 3

# Input proportion of animals in each vulnerable component of the population
# The default is that the entire population is vulnerable
vulnmean <- c(1.0)
nvulnmean <- length(vulnmean)

# Input number of days of "residual" disturbance associated with each day of actual disturbance 
# for the proportion of the population described by prop_days_dist 
# The default is 1, which results in each animal experiencing a total of 2 days of disturbance
days <- 1

# If days is set to a value greater than 0 but less than 1 
# this implies that some animals are disturbed for less than 1 day, 
# e.g. days <- 1/2 implies that they are disturbed for only 12 hours
# and days <- 1/3 implies that they are disturbed for only 8 hours

# "prop_days_dist" is the proportion of disturbed animals that experience 
# the number of days of residual disturbance specified by "days"
prop_days_dist <- 1.0

# if prop_dist_days < 1.0, the remaining individuals (1-prop_days_dist) 
# will experience "other_days" of residual disturbance
# the default value for "othe_days is 0. 
#### If 0 < days =< 1, then other_days MUST be set at its default value of 0#######
other_days <- 0

# skip the next 50 lines if you are only modelling collisions
if (pile_years>0){
  
  # Specify name of csv file that contains information on days on which piling will occur 
  # the name should be placed between the quotation marks: " "
  # there is no need to change this line if you have set pile_years to zero
  piling.file <- "MultPilingOpsMultYears.csv"
  
# Set number of piling Operations to be modelled
  pilesx1 <- 3
# "vulnpile" is a matrix indicating which columns of piling.file are to be combined 
# to predict the effects of piling on each vulnerable component of the population
vulnpile <- matrix(0, nrow = nvulnmean, ncol = pilesx1)

# Indicate which Operations will affect each vulnerable component of the population
# A separate line is required for each vulnerable component of the population.
# Add vulnpile[2,] <- c(,) if there are two vulnerable components, 
# vulnpile[3,] <- c(,) if there are three vulnerable components, and so on.
# In this example, animals in the first vulnerable component are vulnerable to the effects of 
# operations 1 & 3, and animals in the second component are vulnerable to the effects of operation 2
vulnpile[1, ] <- c(1,1,1)


# Input number of animals predicted to experience disturbance during 1 day of piling for each Operation
# This version of iPCoD includes an option to specify that the number of animals that are disturbed
# and experience PTS varies through the year because of changes in density by specifying 
# a value of 4 for the  variable "seasons". If this is the case, separate values can be specified
# for Winter, Spring, Summer and Autumn.  
# The default is that these numbers are the same throughout the year
seasons <- 1
numDt <- numPt <- matrix(c(0),nrow=seasons,ncol=pilesx1)
if (seasons == 1){
  numDt[1,] <- c(70000,70000,70000)
  numPt[1,] <- c(0,0,0)
  } else {
    # input numbers for winter (December, January and February)
      numDt[1,] <- c(111,111,111)
      numPt[1,] <- c(1,1,1)
    # input numbers for spring (March, April and May)
      numDt[2,] <- c(222,222,222)
      numPt[2,] <- c(2,2,2)
    # input numbers for summer (June, July and August)
      numDt[3,] <- c(333,333,333)
      numPt[3,] <- c(3,3,3)
    # input numbers for autumn (September, October and November)
      numDt[4,] <- c(444,444,444)
      numPt[4,] <- c(4,4,4)
    }

# Decide whether or not disturbed animals will avoid ALL piling operations when experiencing residual disturbance. 
# The default is that they will NOT avoid all operations (Avoid = FALSE) 
# unless each sub-population is exposed to noise from more than 2 operations
Avoid <- FALSE
if (pilesx1/nvulnmean > 2) Avoid <- FALSE
}

# Decide if PTS can occur on any day (default) or only on the first occasion that an individual is disturbed. 
# Change Day1 to TRUE if you want animals to be only vulnerable to PTS on the first day they are disturbed
Day1 <- FALSE

# Set number of years for simulation
years <- 25

# Set number of animals predicted to be killed each year as a result of collisions with tidal energy arrays
# or any other activity that results in multiple deaths each year
NCollisions <- 0

############ THE FOLLOWING LINES OF CODE ALLOW THE USER TO INCORPORATE A DENSITY DEPENDENT RESPONSE
############ IF APPROPRIATE INFORMATION IS AVAILABLE
# It uses the density dependent relationship proposed by Taylor & DeMaster (1993)
# Fecundity in year t = Fert_K + (Fert_0 - Fert_K)*(1 - ((N in year t)/K)^z)
# where K is the carrying capacity for the population, Fert_K is the fecundity at K
# Fert_0 is the maximum possible value for fecundity, which occurs when the population is very small
# z determines the shape of the density dependent relationship
# if z = 1 the relationship is a straight line
# if z < 1, most density dependence occurs when the population size < K/2
# if z > 1, most density dependence occurs when the population is close to K

# Set value of exponent. Default is no density dependence, so z = 0
z <- 0
# Set carrying capacity
K <- 2000
Ndist_to_K <- pmean/K
# Set max value for fecundity
Fert_0 <- 0.95
# Convert K to number of females
K <- K*propfemale
# Set fecundity rate at carrying capacity (Fert_K)
Fert_K <- 0.1
# This is set to be the same as Fertility if there is no density dependence
# if z > 0, Fertility is set to the appropriate value for the current population size
if (z == 0){Fert_K <- Fertility} else {
  Fertility <- Fert_K + (Fert_0 - Fert_K)*(1- Ndist_to_K^z)
  if (Fertility < 0) Fertility <- 0
  }
